# Obelisk Python Client

![build-docs](https://img.shields.io/github/workflow/status/predict-idlab/obelisk-python/pages%20build%20and%20deployment?label=docs)

## Installation

## Documentation

[Read the docs](https://predict-idlab.github.io/obelisk-python/)